<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.2
 *
 * @package    GCHelp
 * @subpackage GCHelp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    GCHelp
 * @subpackage GCHelp/admin
 * @author     gCampaner <contato@gcampaner.com.br>
 */
class GCHelp_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.2
	 * @access   private
	 * @var      string    $GCHelp    The ID of this plugin.
	 */
	private $GCHelp;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.2
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.2
	 * @param    string    $GCHelp       The name of this plugin.
	 * @param    string    $version    The version of this plugin.
	 */
	public function __construct( $GCHelp, $version ) {

		$this->GCHelp = $GCHelp;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.2
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in GCHelp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The GCHelp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->GCHelp, plugin_dir_url( __DIR__ ) . 'admin/css/gchelp-style.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.2
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in GCHelp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The GCHelp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->GCHelp, plugin_dir_url(__DIR__).'admin/js/gchelp-script.js', array( 'jquery' ), $this->version, false );
	}

	 
	public function adm_page(){
        add_menu_page( 'GC Help', 'GC Help', 'manage_options', 'gc-help-plugin', array( $this, 'content_adm_page' ), plugin_dir_url(__DIR__).'admin/images/dashicon-gchelp.png' );
	}

	public function gchelpset_settings() {
	    add_settings_section('section', '', null, 'gchelpset');
	    add_settings_field('gchelpset-select', 'Select Barrinha Layout', array( $this, 'gchelpset_select_display' ), 'gchelpset', 'section');  
	    register_setting('section', 'gchelpset-select');
	}

	public function gchelpset_select_display() {
	   ?>
	        <select name="gchelpset-select">
	          <option value="darktech" <?php selected(get_option('gchelpset-select'), 'darktech'); ?>>Dark Tech</option>
	          <option value="lighttech" <?php selected(get_option('gchelpset-select'), 'lighttech'); ?>>Light Tech</option>
	        </select>
	   <?php
	}

	public function content_adm_page() { ?>
	<div>
		<?php screen_icon(); ?>
		<br /><br />
		<h1>Bem vindo ao GC-Help!</h1>
		<form method="post" action="options.php">
			<?php
			settings_fields('section');
			do_settings_sections('gchelpset');
			submit_button('Trocar tema');
			?>
		
		</form>
	</div>

	<?php }
}